@@ -3,7 +3,7 @@ use Moo::Role;
 
 requires '_add_files_to_zip', '_add_string_to_zip';
 
-our $VERSION = '1.000001';
+our $VERSION = '1.000002';
 
 around '_add_files_to_zip' => sub {
     my $orig = shift;
@@ -12,7 +12,7 @@ around '_add_files_to_zip' => sub {
 
     $self->_add_string_to_zip(
         $zip, $self->plist_xml,
-        'extension.popclipext/Config.plist'
+        'Config.plist'
     );
 
     return $orig->( $self, $zip );
